@@ -14,6 +14,9 @@ package deploy
 
 import (
 	"context"
+	"fmt"
+
+	"sigs.k8s.io/controller-runtime/pkg/client"
 
 	chev2 "github.com/eclipse-che/che-operator/api/v2"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -67,3 +70,23 @@ func ReloadCheClusterCR(deployContext *chetypes.DeployContext) error {
 	deployContext.CheCluster = cheCluster
 	return nil
 }
+
+// FindCheClusterCRInNamespace returns CheCluster custom resource from given namespace.
+// If namespace is empty then checluster will be found in any namespace.
+// Only one instance of CheCluster custom resource is expected.
+func FindCheClusterCRInNamespace(cl client.Client, namespace string) (*chev2.CheCluster, error) {
+	cheClusters := &chev2.CheClusterList{}
+	if err := cl.List(context.TODO(), cheClusters, &client.ListOptions{Namespace: namespace}); err != nil {
+		return nil, err
+	}
+
+	num := len(cheClusters.Items)
+	switch num {
+	case 0:
+		return nil, nil
+	case 1:
+		return &cheClusters.Items[0], nil
+	default:
+		return nil, fmt.Errorf("expected one instance of CheCluster custom resources, but '%d' found", len(cheClusters.Items))
+	}
+}
