@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2019-2023 Red Hat, Inc.
+// Copyright (c) 2019-2024 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -35,9 +35,13 @@ func NewPluginRegistryReconciler() *PluginRegistryReconciler {
 
 func (p *PluginRegistryReconciler) Reconcile(ctx *chetypes.DeployContext) (reconcile.Result, bool, error) {
 	if ctx.CheCluster.Spec.Components.PluginRegistry.DisableInternalRegistry {
-		ctx.CheCluster.Status.PluginRegistryURL = ""
-		err := deploy.UpdateCheCRStatus(ctx, "PluginRegistryURL", "")
-		return reconcile.Result{}, err == nil, err
+		if ctx.CheCluster.Status.PluginRegistryURL != "" {
+			ctx.CheCluster.Status.PluginRegistryURL = ""
+			err := deploy.UpdateCheCRStatus(ctx, "PluginRegistryURL", "")
+			return reconcile.Result{}, err == nil, err
+		}
+
+		return reconcile.Result{}, true, nil
 	}
 
 	done, err := p.syncService(ctx)
