@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2019-2021 Red Hat, Inc.
+// Copyright (c) 2019-2023 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -9,6 +9,7 @@
 // Contributors:
 //   Red Hat, Inc. - initial API and implementation
 //
+
 package server
 
 import (
@@ -287,95 +288,109 @@ func TestMountBitbucketOAuthEnvVar(t *testing.T) {
 }
 
 func TestMountGitHubOAuthEnvVar(t *testing.T) {
-	type testCase struct {
-		name                              string
-		initObjects                       []runtime.Object
-		expectedIdKeyPath                 string
-		expectedSecretKeyPath             string
-		expectedOAuthEndpoint             string
-		expectedDisableSubdomainIsolation string
-		expectedVolume                    corev1.Volume
-		expectedVolumeMount               corev1.VolumeMount
-	}
-
-	testCases := []testCase{
-		{
-			name: "Test",
-			initObjects: []runtime.Object{
-				&corev1.Secret{
-					TypeMeta: metav1.TypeMeta{
-						Kind:       "Secret",
-						APIVersion: "v1",
-					},
-					ObjectMeta: metav1.ObjectMeta{
-						Name:      "github-oauth-config",
-						Namespace: "eclipse-che",
-						Labels: map[string]string{
-							"app.kubernetes.io/part-of":   "che.eclipse.org",
-							"app.kubernetes.io/component": "oauth-scm-configuration",
-						},
-						Annotations: map[string]string{
-							"che.eclipse.org/oauth-scm-server":                       "github",
-							"che.eclipse.org/scm-server-endpoint":                    "endpoint_1",
-							"che.eclipse.org/scm-github-disable-subdomain-isolation": "true",
-						},
-					},
-					Data: map[string][]byte{
-						"id":     []byte("some_id"),
-						"secret": []byte("some_secret"),
-					},
-				},
+	secret1 := &corev1.Secret{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       "Secret",
+			APIVersion: "v1",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "github-oauth-config",
+			Namespace: "eclipse-che",
+			Labels: map[string]string{
+				"app.kubernetes.io/part-of":   "che.eclipse.org",
+				"app.kubernetes.io/component": "oauth-scm-configuration",
 			},
-			expectedIdKeyPath:                 "/che-conf/oauth/github/id",
-			expectedSecretKeyPath:             "/che-conf/oauth/github/secret",
-			expectedOAuthEndpoint:             "endpoint_1",
-			expectedDisableSubdomainIsolation: "true",
-			expectedVolume: corev1.Volume{
-				Name: "github-oauth-config",
-				VolumeSource: corev1.VolumeSource{
-					Secret: &corev1.SecretVolumeSource{
-						SecretName: "github-oauth-config",
-					},
-				},
-			},
-			expectedVolumeMount: corev1.VolumeMount{
-				Name:      "github-oauth-config",
-				MountPath: "/che-conf/oauth/github",
+			Annotations: map[string]string{
+				"che.eclipse.org/oauth-scm-server":                       "github",
+				"che.eclipse.org/scm-server-endpoint":                    "endpoint_1",
+				"che.eclipse.org/scm-github-disable-subdomain-isolation": "true",
 			},
 		},
+		Data: map[string][]byte{
+			"id":     []byte("some_id_1"),
+			"secret": []byte("some_secret_1"),
+		},
 	}
 
-	for _, testCase := range testCases {
-		t.Run(testCase.name, func(t *testing.T) {
-			ctx := test.GetDeployContext(nil, testCase.initObjects)
-
-			server := NewCheServerReconciler()
-			deployment, err := server.getDeploymentSpec(ctx)
-			assert.Nil(t, err, "Unexpected error %v", err)
-
-			container := &deployment.Spec.Template.Spec.Containers[0]
-
-			value := utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTID__FILEPATH", container.Env)
-			assert.Equal(t, testCase.expectedIdKeyPath, value)
-
-			value = utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTSECRET__FILEPATH", container.Env)
-			assert.Equal(t, testCase.expectedSecretKeyPath, value)
-
-			value = utils.GetEnvByName("CHE_INTEGRATION_GITHUB_OAUTH__ENDPOINT", container.Env)
-			assert.Equal(t, testCase.expectedOAuthEndpoint, value)
-
-			value = utils.GetEnvByName("CHE_INTEGRATION_GITHUB_DISABLE__SUBDOMAIN__ISOLATION", container.Env)
-			assert.Equal(t, testCase.expectedDisableSubdomainIsolation, value)
-
-			volume := test.FindVolume(deployment.Spec.Template.Spec.Volumes, "github-oauth-config")
-			assert.NotNil(t, volume)
-			assert.Equal(t, testCase.expectedVolume, volume)
-
-			volumeMount := test.FindVolumeMount(container.VolumeMounts, "github-oauth-config")
-			assert.NotNil(t, volumeMount)
-			assert.Equal(t, testCase.expectedVolumeMount, volumeMount)
-		})
+	secret2 := &corev1.Secret{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       "Secret",
+			APIVersion: "v1",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      "github-oauth-config_2",
+			Namespace: "eclipse-che",
+			Labels: map[string]string{
+				"app.kubernetes.io/part-of":   "che.eclipse.org",
+				"app.kubernetes.io/component": "oauth-scm-configuration",
+			},
+			Annotations: map[string]string{
+				"che.eclipse.org/oauth-scm-server":                       "github",
+				"che.eclipse.org/scm-server-endpoint":                    "endpoint_2",
+				"che.eclipse.org/scm-github-disable-subdomain-isolation": "false",
+			},
+		},
+		Data: map[string][]byte{
+			"id":     []byte("some_id_2"),
+			"secret": []byte("some_secret_2"),
+		},
 	}
+
+	ctx := test.GetDeployContext(nil, []runtime.Object{secret1, secret2})
+
+	server := NewCheServerReconciler()
+	deployment, err := server.getDeploymentSpec(ctx)
+	assert.Nil(t, err, "Unexpected error %v", err)
+
+	container := &deployment.Spec.Template.Spec.Containers[0]
+
+	assert.Equal(t, "/che-conf/oauth/github/id", utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTID__FILEPATH", container.Env))
+	assert.Equal(t, "/che-conf/oauth/github__2/id", utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTID__FILEPATH__2", container.Env))
+
+	assert.Equal(t, "/che-conf/oauth/github/secret", utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTSECRET__FILEPATH", container.Env))
+	assert.Equal(t, "/che-conf/oauth/github__2/secret", utils.GetEnvByName("CHE_OAUTH2_GITHUB_CLIENTSECRET__FILEPATH__2", container.Env))
+
+	assert.Equal(t, "endpoint_1", utils.GetEnvByName("CHE_INTEGRATION_GITHUB_OAUTH__ENDPOINT", container.Env))
+	assert.Equal(t, "endpoint_2", utils.GetEnvByName("CHE_INTEGRATION_GITHUB_OAUTH__ENDPOINT__2", container.Env))
+
+	assert.Equal(t, "true", utils.GetEnvByName("CHE_INTEGRATION_GITHUB_DISABLE__SUBDOMAIN__ISOLATION", container.Env))
+	assert.Equal(t, "false", utils.GetEnvByName("CHE_INTEGRATION_GITHUB_DISABLE__SUBDOMAIN__ISOLATION__2", container.Env))
+
+	assert.Equal(t,
+		corev1.Volume{
+			Name: "github-oauth-config",
+			VolumeSource: corev1.VolumeSource{
+				Secret: &corev1.SecretVolumeSource{
+					SecretName: "github-oauth-config",
+				},
+			},
+		},
+		test.FindVolume(deployment.Spec.Template.Spec.Volumes, "github-oauth-config"))
+
+	assert.Equal(t,
+		corev1.Volume{
+			Name: "github-oauth-config_2",
+			VolumeSource: corev1.VolumeSource{
+				Secret: &corev1.SecretVolumeSource{
+					SecretName: "github-oauth-config_2",
+				},
+			},
+		},
+		test.FindVolume(deployment.Spec.Template.Spec.Volumes, "github-oauth-config_2"))
+
+	assert.Equal(t,
+		corev1.VolumeMount{
+			Name:      "github-oauth-config",
+			MountPath: "/che-conf/oauth/github",
+		},
+		test.FindVolumeMount(container.VolumeMounts, "github-oauth-config"))
+
+	assert.Equal(t,
+		corev1.VolumeMount{
+			Name:      "github-oauth-config_2",
+			MountPath: "/che-conf/oauth/github__2",
+		},
+		test.FindVolumeMount(container.VolumeMounts, "github-oauth-config_2"))
 }
 
 func TestMountAzureDevOpsOAuthEnvVar(t *testing.T) {
